@@ -27,7 +27,7 @@ def dirname():
     return os.path.dirname(os.path.realpath(__file__))
 
 def file_in_dir(filename):
-    return os.path.join(dirname(), filename)
+    return os.path.join(dirname(), 'data', filename)
 
 def open_slides():
     cmd = "landslide -o out.html {0}".format(file_in_dir('slides.md'))
@@ -36,7 +36,8 @@ def open_slides():
     Generator(slides_path, **{
         'embed': True,
         'relative': True,
-        'destination_file': output_path
+        'destination_file': output_path,
+        'theme': file_in_dir('avalanche'),
     }).execute()
     call(['open', output_path])
 
